@@ -90,7 +90,7 @@ class CalendarBase:
             positive = s.positive
             ms = s.microsecond + o.microsecond
             secs = s.second + o.second
-            if ms > 1000000:
+            if ms >= 1000000:
                  ms -= 1000000
                  secs += 1
         else:
@@ -203,7 +203,7 @@ class LPDateTime(CalendarBase):
 
 class LPInterval:
     def __init__(self, start, end, fuzzy_start = None, fuzzy_end = None, fuzzy_function = None):
-        # Valid values for fuzzy_membership_function are "trapezoidal", "logistic" and "gaussian"
+        # Valid values for fuzzy_function are "trapezoidal", "logistic" and "gaussian"
         self.start = start
         self.end = end
         if fuzzy_start == None:
